@@ -11,7 +11,6 @@ from collections.abc import MutableMapping
 from typing import Any, Dict, List, Union, Optional, TypeVar, Iterable, Set
 
 from overrides import overrides
-from cached_path import cached_path
 
 # _jsonnet doesn't work on Windows, so we have to use fakes.
 try:
@@ -509,6 +508,8 @@ class Params(MutableMapping):
             ext_vars = {}
 
         # redirect to cache, if necessary
+        from cached_path import cached_path
+
         params_file: Path = Path(cached_path(params_file))
 
         file_dict: Dict[str, Any]
@@ -555,18 +556,6 @@ class Params(MutableMapping):
         params_dict = self.as_dict(quiet=True)
         if not preference_orders:
             preference_orders = []
-            preference_orders.append(
-                [
-                    "dataset_reader",
-                    "iterator",
-                    "model",
-                    "train_data_path",
-                    "validation_data_path",
-                    "test_data_path",
-                    "trainer",
-                    "vocabulary",
-                ]
-            )
             preference_orders.append(["type"])
 
         def order_func(key):
