@@ -12,7 +12,6 @@ from typing import (
     cast,
     TypeVar,
     Generic,
-    Iterator,
     Callable,
     TYPE_CHECKING,
 )
@@ -39,7 +38,6 @@ from tango.common.from_params import (
 )
 from tango.common.logging import TangoLogger
 from tango.format import Format, DillFormat
-from tango.step_cache import StepCache
 
 if TYPE_CHECKING:
     from tango.executor import Executor
@@ -65,10 +63,10 @@ class Step(Registrable, Generic[T]):
       error messages and the like, and has no consequence on the actual computation.
     * ``cache_results`` specifies whether the results of this step should be cached. If this is
       ``False``, the step is recomputed every time it is needed. If this is not set at all,
-      we cache if the step is marked as :attr:`DETERMINISTIC`, and we don't cache otherwise.
+      and :attr:`CACHEABLE` is ``True``, we cache if the step is marked as :attr:`DETERMINISTIC`,
+      and we don't cache otherwise.
     * ``step_format`` gives you a way to override the step's default format (which is given in :attr:`FORMAT`).
-    * ``only_if_needed`` specifies whether we can skip this step if no other step depends on it. The
-      default for this setting is to set it for all steps that don't have an explicit name.
+    * ``step_config`` is the original raw part of the experiment config corresponding to this step.
     """
 
     DETERMINISTIC: bool = False
@@ -97,11 +95,13 @@ class Step(Registrable, Generic[T]):
         step_name: Optional[str] = None,
         cache_results: Optional[bool] = None,
         step_format: Optional[Format] = None,
-        only_if_needed: Optional[bool] = None,
+        step_config: Optional[Dict[str, Any]] = None,
         **kwargs,
     ):
         self.logger = cast(TangoLogger, logging.getLogger(self.__class__.__name__))
 
+        self.config = step_config
+
         if self.VERSION is not None:
             assert _version_re.match(
                 self.VERSION
@@ -157,13 +157,6 @@ class Step(Registrable, Generic[T]):
                 f"Step {self.name}'s cache_results parameter is set to an invalid value."
             )
 
-        if step_name is None:
-            self.only_if_needed = True
-        else:
-            self.only_if_needed = not self.cache_results
-        if only_if_needed is not None:
-            self.only_if_needed = only_if_needed
-
         self.work_dir_for_run: Optional[
             Path
         ] = None  # This is set only while the run() method runs.
@@ -275,10 +268,18 @@ class Step(Registrable, Generic[T]):
 
     @abstractmethod
     def run(self, **kwargs) -> T:
-        """Execute the step's action."""
+        """
+        Execute the step's action.
+
+        This method needs to be implemented when creating a ``Step`` subclass, but
+        it shouldn't be called directly. Instead, call :meth:`run_with_work_dir()`.
+        """
         raise NotImplementedError()
 
-    def _run_with_work_dir(self, cache: StepCache) -> T:
+    def run_with_work_dir(self, work_dir_for_run: Path) -> T:
+        """
+        Run the step with a working directory.
+        """
         if self.work_dir_for_run is not None:
             raise ValueError("You can only run a Step's run() method once at a time.")
 
@@ -287,9 +288,8 @@ class Step(Registrable, Generic[T]):
         if self.DETERMINISTIC:
             random.seed(784507111)
 
-        step_dir = cache.path_for_step(self)
-        self.work_dir_for_run = step_dir / "work"
         try:
+            self.work_dir_for_run = work_dir_for_run
             self.work_dir_for_run.mkdir(exist_ok=True, parents=True)
             return self.run(**self.kwargs)
         finally:
@@ -299,13 +299,16 @@ class Step(Registrable, Generic[T]):
     @property
     def work_dir(self) -> Path:
         """
-        Returns a work directory that a step can use while its ``run()`` method runs.
+        The working directory that a step can use while its ``run()`` method runs.
 
         This directory stays around across restarts. You cannot assume that it is empty when your
         step runs, but you can use it to store information that helps you restart a step if it
         got killed half-way through the last time it ran."""
         if self.work_dir_for_run is None:
-            raise ValueError("You can only call this method while the step is running.")
+            raise RuntimeError(
+                "You can only call this method while the step is running with a working directory. "
+                "Did you call '.run()' directly? You should only run a step with 'run_with_work_dir()'."
+            )
         return self.work_dir_for_run
 
     @property
@@ -320,22 +323,6 @@ class Step(Registrable, Generic[T]):
         else:
             return self._executor
 
-    def result(self, cache: StepCache) -> T:
-        """Returns the result of this step. If the results are cached, it returns those. Otherwise it
-        runs the step and returns the result from there."""
-        if self in cache:
-            return cache[self]
-
-        result = self._run_with_work_dir(cache)
-        if self.cache_results:
-            cache[self] = result
-            if hasattr(result, "__next__"):
-                assert isinstance(result, Iterator)
-                # Caching the iterator will consume it, so we write it to the cache and then read from the cache
-                # for the return value.
-                return cache[self]
-        return result
-
     def det_hash_object(self) -> Any:
         return self.unique_id
 
